<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>鸣谢</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>参与与帮助</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>是一个快速创建桌面截屏的跨平台应用。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>这是一个使用Qt编写的，轻巧而强大的应用程序。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation>使用 Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>网站 - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>根据&lt;a href=%1&gt;GPL v2&lt;/a&gt;许可</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>您可以加入我们，并在需要时为我们提供帮助。如果您喜欢此应用程序，这是一个邀请。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>你可以做什么？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>使用其他语言来翻译ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>对下一个版本提出建议</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>报告错误和问题</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>错误追踪</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>翻译：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Brazilian Portuguese translation</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation>Marcio Moraes</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Ukrainian translation</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation>Gennadi Motsyo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Spanish translation</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation>Burjans L García D</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Italian translation</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>测试：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>双监视器支持和其他Linux支持</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Linux中的双显示器支持</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>win32-build [Windows XP and 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>旧的 win32-build [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation>win32-build [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>文件夹 %1 不存在，你要创建吗？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
        <source>Select directory</source>
        <translation>选择文件夹</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>是否要将设置重设为默认值？</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
        <source>Example: </source>
        <translation>例如： </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>此密钥已在ScreenGrab中使用！请选择另一个。</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
        <source>This key is not supported on your system!</source>
        <translation>您的系统不支持此密钥！</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="64"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>是用于快速创建桌面屏幕截图的跨平台应用程序。</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="68"/>
        <source>Take a fullscreen screenshot</source>
        <translation>截取全屏截图</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="72"/>
        <source>Take a screenshot of the active window</source>
        <translation>截取活动窗口的屏幕截图</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="76"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>截取选中区域屏幕截图</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="80"/>
        <source>Run the application with a hidden main window</source>
        <translation>使用隐藏的主窗口运行应用程序</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved</source>
        <translation>已保存</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved to </source>
        <translation>已保存到 </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>保存的文件已经复制到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="478"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>保存的文件路径已复制到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Copied</source>
        <translation>已复制</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>截屏已复制到剪贴板</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>截屏的类型</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>屏幕区域</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>最后选中的区域</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>延迟：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>截屏前延迟几秒</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>鼠标周围的缩放区域</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>无窗口装饰</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>包含鼠标指针</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>工具栏</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>新</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
        <source>Screenshot </source>
        <translation>截屏 </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>双击以在外部默认图像查看器中打开屏幕截图</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
        <source>Show</source>
        <translation>展示</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
        <source>%1 Files</source>
        <translation>%1 文件</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
        <source>Save As...</source>
        <translation>保存为…</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>点击并拖动以绘制一个矩形，
右键单击以适合边缘，
双击或按Enter
截图。</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixels </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>外部编辑</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>编辑在…</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>关于 Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="568"/>
        <source>Options</source>
        <translation>选项</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>主</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>系统托盘</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>捷径</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>默认保存目录</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>选择默认的保存路径</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>浏览文件系统</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>浏览</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>默认文件</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>名字：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>默认文件名</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>图片的默认保存格式</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>保存时复制文件名到剪贴板</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>不复制</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>只复制文件名</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>复制文件的全路径</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>图片质量</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>图片质量（1-小文件，100-高质量）</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>将当前日期时间插入保存的文件名</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>在文件名中插入当前日期和时间</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>模板： </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>例子： </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>在抓取过程中自动保存屏幕截图</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>自动保存截屏</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>保存第一个截屏</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>允许运行ScreenGrab的多个副本</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>允许运行ScreenGrab的多个实例</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>双击在外部查看器中打开</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>启用外部查看器</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>如果未选中，则所选区域
可能会变大以适合外部边缘</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>右键单击以适合选定区域内的边缘</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="418"/>
        <source>Notify on saving and copying</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="427"/>
        <source>Duration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="494"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>在系统托盘中显示ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="434"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="501"/>
        <source>Minimize to tray on click close button</source>
        <translation>点击关闭按钮最小化到托盘</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="504"/>
        <source>Minimize to tray when closing</source>
        <translation>关闭时最小化到托盘</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="543"/>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="548"/>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="553"/>
        <source>New screen</source>
        <translation>新的屏幕</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Save screen</source>
        <translation>保存屏幕</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="563"/>
        <source>Copy screen</source>
        <translation>复制屏幕</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="573"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="578"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="588"/>
        <source>Selected shortcut:</source>
        <translation>选择的快捷键：</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="595"/>
        <source>Not defined</source>
        <translation>未声明</translation>
    </message>
</context>
</TS>
